#
# spec file for package python-quicktions
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-quicktions
Version:        1.18
Release:        1.3
Summary:        Fast fractions data type for rational numbers
License:        Python-2.0
Group:          Development/Languages/Python
URL:            https://github.com/scoder/quicktions
Source:         https://files.pythonhosted.org/packages/source/q/quicktions/quicktions-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 3}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Python's Fraction data type is an excellent way to do exact money
calculations and largely beats Decimal in terms of simplicity,
accuracy and safety.  Clearly not in terms of speed, though, given
the cdecimal accelerator in Py3.3+.

Quicktions is an adaptation of the original fractions module
(as included in CPython 3.5) that is compiled and optimised with
Cython into a fast, native extension module.

Compared to the standard library fractions module in Py2.7 and
Py3.4, quicktions is currently about 10x faster, and still about
6x faster than the current version in Python 3.5.  It's also about
15x faster than the (Python implemented) decimal module in Py2.7.

%prep
%setup -q -n quicktions-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export PYTHONDONTWRITEBYTECODE=1
%pytest_arch --capture=no

%files %{python_files}
%doc CHANGES.rst README.rst
%license LICENSE
%{python_sitearch}/quicktions.cpython-*so
%{python_sitearch}/quicktions-%{version}.dist-info

%changelog
* Mon Jun 10 2024 Dirk Müller <dmueller@suse.com>
- update to 1.18:
  * New binary wheels were added built with gcc 12
    (manylinux_2_28).
- use PEP517/wheel build
* Mon Mar 25 2024 Dirk Müller <dmueller@suse.com>
- update to 1.17:
  * Math operations were sped up by inlined binary GCD
    calculation.
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 1.16:
  * Formatting support was improved, following CPython 3.13a3 as
    of https://github.com/python/cpython/pull/111320
  * Add support for Python 3.13 by using Cython 3.0.8 and calling
    math.gcd().
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 1.15:
  * Add support for Python 3.12 by using Cython 3.0.2.
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- use generic Cython dependency >= 3.0
* Mon Mar 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Enable python 3.11 build again, now is supported
- Update to 1.14
  - Implement __format__ for Fraction, following python/cpython#100161
  - Implement Fraction.is_integer(), following python/cpython#100488
  - Fraction.limit_denominator() is faster, following
    python/cpython#93730
  - Internal creation of result Fractions is about 10%% faster if the
    calculated numerator/denominator pair is already normalised,
    following python/cpython#101780
  - Built using Cython 3.0.0b1.
- 1.13
  - Parsing very long numbers from a fraction string was very slow,
    even slower than fractions.Fraction. The parser is now faster in
    all cases (and still much faster for shorter numbers).
  - Fraction did not implement __int__.
    https://bugs.python.org/issue44547
- 1.12
  - Faster and more space friendly pickling and unpickling.
    https://bugs.python.org/issue44154
  - Algorithmically faster arithmetic for large denominators, although
    slower for small fraction components.
    https://bugs.python.org/issue43420 Original patch for CPython by
    Sergey B. Kirpichev and Raymond Hettinger.
  - Make sure bool(Fraction) always returns a bool.
    https://bugs.python.org/issue39274
  - Built using Cython 3.0.0a10.
* Tue Feb 21 2023 Daniel Garcia <daniel.garcia@suse.com>
- Skip python 3.11, it's not supported yet
  gh#scoder/quicktions#6
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 1.11
  * Fix ``OverflowError`` when parsing string values with long decimal parts.
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.10:
  * New method fraction.as_integer_ratio()
  * python 3.8 fixes
* Tue May 14 2019 John Jolly <jjolly@suse.com>
- Update to 1.9
  + Substantially faster normalisation (and therefore instantiation)
    in Py3.5+.
  + // (floordiv) now follows the expected rounding behaviour when used
    with floats (by converting to float first), and is much faster for
    integer operations.
  + Fix return type of divmod(), where the first item should be an integer.
  + Further speed up mod and divmod operations.
- Update to 1.8
  + Faster mod and divmod calculation.
- Update to 1.7
  + Faster normalisation and fraction string parsing.
  + Add support for Python 3.7.
  + Built using Cython 0.29.
- Changed %%check to use %%pytest_arch
* Fri Jun 15 2018 toddrme2178@gmail.com
- Use more compatible py.test syntax.
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 1.6
  * Speed up Fraction creation from a string value by 3-5x.
  * Built using Cython 0.28.1.
- Update to 1.5
  * Result of power operator (``**``) was not normalised for negative values.
  * Built using Cython 0.27.2.
- Update to 1.4
  * Rebuilt using Cython 0.26.1 to improve support of Python 3.7.
- Update to 1.3
  * repair the faster instantiation from Decimal values in Python 3.6
  * avoid potential glitch for certain large numbers in normalisation under Python 2.x
- Update to 1.2
  * change hash function in Python 2.x to match that of ``fractions.Fraction``
- Update to 1.1
  * faster instantiation from float values
  * faster instantiation from Decimal values in Python 3.6
- Update to 1.0
  * ``Fraction.imag`` property could return non-zero
  * parsing strings with long fraction parts could use an incorrect scale
- Implement single-spec version
* Thu Sep  3 2015 toddrme2178@gmail.com
- Update to 0.7 (2014-10-09)
  * faster instantiation from float and string values
    fix test in Python 2.x
- Update to 0.6 (2014-10-09)
  * faster normalisation (and thus instantiation)
* Wed Oct  8 2014 toddrme2178@gmail.com
- Initial version
